# qluster

Quick clusters of merging binary black holes: `pip install qluster`.

Based on [Gerosa and Berti (2019) arXiv:1906.05295](https://arxiv.org/abs/1906.05295) and [Mould, Gerosa, and Taylor (2022) arXiv:2203.03651](https://arxiv.org/abs/2203.03651).
